<!-- markdownlint-disable -->

<a href="../spherapy/util/constants.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `util.constants`
Namespace of useful orbital constants. 

**Global Variables**
---------------
- **M_EARTH**
- **M_SUN**
- **M_MOON**
- **M_MARS**
- **R_SUN**
- **R_EARTH**
- **R_MOON**
- **R_MARS**
- **SUN_MIN_ALT**
- **EARTH_MIN_ALT**
- **MOON_MIN_ALT**
- **MARS_MIN_ALT**
- **G**
- **GM_EARTH**
- **GM_SUN**
- **GM_MOON**
- **GM_MARS**
- **AU**
- **J2**
- **W_EARTH**
- **SB_SIGMA**
- **T_EARTH**
- **T_SUN**
- **T_SPACE**
- **SOL_CONST**
- **L_SUN**
- **DAY_IN_MINS**
- **HALF_HOUR**
- **SECS_PER_DAY**




---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
